==> pshkcms-core-1.0.9-a52739.tar: src/Model/Helpers/DataToFormInputs.php <==
<?php declare(strict_types = 1);

namespace Core\Model\Helpers;

use Core\Model\TemplateReader\TemplateTextTypesCollection;
use Core\Model\UI\Form\BaseContainer;
use Core\Model\UI\Form\Controls\CheckboxListInput;
use Core\Model\UI\Form\Controls\HiddenInput;
use Core\Model\UI\Form\Controls\SelectInput;
use Nette\Localization\ITranslator;
use Nette\Utils\Json;
use Tracy\Debugger;

class DataToFormInputs
{
	/** @var TemplateTextTypesCollection */
	protected $typesCollection;

	/** @var ITranslator */
	protected $translator;

	public function __construct(TemplateTextTypesCollection $typesCollection, ITranslator $translator)
	{
		$this->typesCollection = $typesCollection;
		$this->translator      = $translator;
	}

	/**
	 * @param BaseContainer $container
	 * @param array         $data
	 *
	 * @return array
	 */
	public function parseData(BaseContainer &$container, array $data): array
	{
		$structure    = ['sections' => []];
		$sectionNames = [];
		$groupNames   = [];

		foreach ($data as $v) {
			$item = $this->typesCollection->getItemByType($v['type'] ?? 'textarea');

			if ($item && $v['name']) {
				if ($v['title']) {
					$v['title'] = $this->translator->translate(...$v['title']);
					$item->setTitle($v['title']);
				}

				$item->setName($v['name']);

				$s = &$structure;

				if (isset($v['section'])) {
					if (isset($v['sectionName']))
						$sectionNames[$v['section']] = $this->translator->translate(...(array) $v['sectionName']);
					if (!isset($s['sections'][$v['section']]))
						$s['sections'][$v['section']] = [];
					$s = &$s['sections'][$v['section']];
				}

				if (isset($v['group'])) {
					if (isset($v['groupName']))
						$groupNames[$v['group']] = $this->translator->translate(...(array) $v['groupName']);
					if (!isset($s[$v['group']]))
						$s[$v['group']] = [];
					$s = &$s[$v['group']];
				}

				$s[] = $v['name'];
				$item->loadContainer($container, $v);
			}
		}

		foreach ($structure['sections'] as $sk => $sv) {
			if (array_key_exists($sk, $sectionNames)) {
				$structure['sections'][$sectionNames[$sk]] = $sv;
				unset($structure['sections'][$sk]);
			}
		}

		foreach ($structure['sections'] as $sk => $sv) {
			if (is_array($sv)) {
				foreach ($sv as $gk => $gv) {
					if (array_key_exists($gk, $groupNames)) {
						$structure['sections'][$sk][$groupNames[$gk]] = $gv;
						unset($structure['sections'][$sk][$gk]);
					}
				}
			}
		}

		return [
			'structure' => $structure,
		];
	}

	/**
	 * @param BaseContainer $container
	 * @param array         $data
	 */
	public function setDefaults(BaseContainer $container, array $data): void
	{
		foreach ($container->getComponents() as $k => $c) {
			$value = $data[$k] ?? null;

			if ($c->getIsMultiLanguage() && is_string($value)) {
				try {
					$value = Json::decode($value, true);
				} catch (\Exception $e) {
				}
			}

			if (!$value)
				continue;

			if ($c instanceof SelectInput) {
				if (array_key_exists($value, $c->getItems())) {
					$c->setDefaultValue($value);
				}
			} else if ($c instanceof CheckboxListInput) {
				$tmp = [];
				foreach ($value as $v) {
					if (array_key_exists($v, $c->getItems()))
						$tmp[] = $v;
				}

				$c->setDefaultValue($tmp);
			} else if ($c instanceof HiddenInput) {
				$c->reSetValue($value);
			} else if ($c instanceof \Nette\Forms\Controls\BaseControl) {
				$c->setDefaultValue($value);
			} else if ($c instanceof BaseContainer) {
				$this->setDefaults($c, $value);
			}
		}
	}
}

==> pshkcms-core-1.1.0-832478.tar: src/Model/Helpers/DataToFormInputs.php <==
<?php declare(strict_types = 1);

namespace Core\Model\Helpers;

use Core\Model\TemplateReader\TemplateTextTypesCollection;
use Core\Model\UI\Form\BaseContainer;
use Core\Model\UI\Form\Controls\CheckboxListInput;
use Core\Model\UI\Form\Controls\HiddenInput;
use Core\Model\UI\Form\Controls\SelectInput;
use Nette\Localization\ITranslator;
use Nette\Utils\Json;
use Tracy\Debugger;

class DataToFormInputs
{
	/** @var TemplateTextTypesCollection */
	protected $typesCollection;

	/** @var ITranslator */
	protected $translator;

	public function __construct(TemplateTextTypesCollection $typesCollection, ITranslator $translator)
	{
		$this->typesCollection = $typesCollection;
		$this->translator      = $translator;
	}

	/**
	 * @param BaseContainer $container
	 * @param array         $data
	 *
	 * @return array
	 */
	public function parseData(BaseContainer &$container, array $data): array
	{
		$structure    = ['sections' => []];
		$sectionNames = [];
		$groupNames   = [];

		foreach ($data as $v) {
			$item = $this->typesCollection->getItemByType($v['type'] ?? 'textarea');

			if ($item && $v['name']) {
				if ($v['title']) {
					$v['title'] = $this->translator->translate(...$v['title']);
					$item->setTitle($v['title']);
				}

				$item->setName($v['name']);

				$s = &$structure;

				if (isset($v['section'])) {
					if (isset($v['sectionName']))
						$sectionNames[$v['section']] = $this->translator->translate(...(array) $v['sectionName']);
					if (!isset($s['sections'][$v['section']]))
						$s['sections'][$v['section']] = [];
					$s = &$s['sections'][$v['section']];
				}

				if (isset($v['group'])) {
					if (isset($v['groupName']))
						$groupNames[$v['group']] = $this->translator->translate(...(array) $v['groupName']);
					if (!isset($s[$v['group']]))
						$s[$v['group']] = [];
					$s = &$s[$v['group']];
				}

				if (isset($v['default']))
					$item->setDefault($v['default']);

				$s[] = $v['name'];
				if (!$container->getComponent($v['name'], false))
					$item->loadContainer($container, $v);

				if (isset($v['default']))
					$container[$v['name']]->setDefaultValue($v['default']);
			}
		}

		foreach ($structure['sections'] as $sk => $sv) {
			if (array_key_exists($sk, $sectionNames)) {
				$structure['sections'][$sectionNames[$sk]] = $sv;
				unset($structure['sections'][$sk]);
			}
		}

		foreach ($structure['sections'] as $sk => $sv) {
			if (is_array($sv)) {
				foreach ($sv as $gk => $gv) {
					if (array_key_exists($gk, $groupNames)) {
						$structure['sections'][$sk][$groupNames[$gk]] = $gv;
						unset($structure['sections'][$sk][$gk]);
					}
				}
			}
		}

		return [
			'structure' => $structure,
		];
	}

	/**
	 *
	 * @param BaseContainer $container
	 * @param array         $data
	 */
	public function setDefaults(BaseContainer $container, array $data): void
	{
		foreach ($container->getComponents() as $k => $c) {
			$value = $data[$k] ?? null;

			if ($c->getIsMultiLanguage() && is_string($value)) {
				try {
					$value = Json::decode($value, Json::FORCE_ARRAY);
				} catch (\Exception $e) {
				}
			}

			if (!$value)
				continue;

			if ($c instanceof SelectInput) {
				if (array_key_exists($value, $c->getItems())) {
					$c->setDefaultValue($value);
				}
			} else if ($c instanceof CheckboxListInput) {
				$tmp = [];
				foreach ($value as $v) {
					if (array_key_exists($v, $c->getItems()))
						$tmp[] = $v;
				}

				$c->setDefaultValue($tmp);
			} else if ($c instanceof HiddenInput) {
				$c->reSetValue($value);
			} else if ($c instanceof \Nette\Forms\Controls\BaseControl) {
				$c->setDefaultValue($value);
			} else if ($c instanceof BaseContainer) {
				$this->setDefaults($c, $value);
			}
		}
	}
}
